@@ -1,7 +1,11 @@
+#!/usr/bin/env python
+# -*- coding: utf8 -*-
+
 import os, os.path, shutil, logging, sys, filecmp, stat, re, time
 import shlex, subprocess
 
 
+
 from puke.FileList import *
 from puke.Console import *
 from scss import Scss
@@ -190,7 +194,7 @@ def sh (command, header = None, output = True, timeout = None):
         signal.alarm(timeout)  # 5 seconds
 
     try:
-        cProcess = subprocess.Popen(command, stdout = subprocess.PIPE, shell = True, stderr= subprocess.PIPE)
+        cProcess = subprocess.Popen(command, stdout = subprocess.PIPE, shell = True, stderr= subprocess.PIPE, executable='/bin/bash', env=os.environ)
         (stdout, error) = cProcess.communicate()
         signal.alarm(0)
     except Alarm:
@@ -324,7 +328,10 @@ def stats(file_list, title = ""):
     lines = __exec("wc -l %s | tail -1" % ' '.join(file_list))
     lines =  re.findall(r'\d+(?:\.\d+)?', lines)
     if len(lines):
-        lines = int(lines.pop())
+        try:
+            lines = int(lines.pop(0))
+        except:
+            lines = 0
     else:
         lines = 0
     
